@@ -90,9 +90,18 @@ class PostgresTargetConnector(C8Connector):
                            description='PostgreSQL database name.',
                            default_value='postgres'),
             ConfigProperty('default_target_schema', 'Target Schema', ConfigAttributeType.STRING, True, False,
-                           description='Name of the schema where the tables will be created. If "schema_mapping" '
-                                       'is not defined then every stream is loaded into this schema.',
+                           description='Destination Schema name.',
                            placeholder_value='public'),
+            ConfigProperty('target_table', 'Target Table', ConfigAttributeType.STRING, True, False,
+                           description='Destination table name.',
+                           placeholder_value='my_table'),
+            ConfigProperty('hard_delete', 'Hard Delete', ConfigAttributeType.BOOLEAN, True, False,
+                           description='When `hard_delete` option is true then DELETE SQL commands will be performed '
+                                       'in Postgres to delete rows in tables. It is achieved by continuously checking '
+                                       'the `_SDC_DELETED_AT` metadata column sent by the singer tap. Due to deleting '
+                                       'rows requires metadata columns, `hard_delete` option automatically enables the'
+                                       ' `add_metadata_columns` option as well.',
+                           default_value='false'),
             ConfigProperty('batch_size_rows', 'Batch Size', ConfigAttributeType.INT, False, False,
                            description='Maximum number of rows inserted per batch.',
                            default_value='100000'),
@@ -114,15 +123,15 @@ class PostgresTargetConnector(C8Connector):
                                        'Any other positive number will create that number of threads, up to '
                                        'parallelism_max.',
                            default_value='0'),
-            ConfigProperty('max_parallelism', 'Maximum Paralellism', ConfigAttributeType.INT, False, False,
+            ConfigProperty('max_parallelism', 'Maximum Parallelism', ConfigAttributeType.INT, False, False,
                            description='Maximum number of parallel threads used to flush tables.',
                            default_value='16'),
-            ConfigProperty('default_target_schema_select_permission', 'Targert Schema Privileges',
+            ConfigProperty('default_target_schema_select_permission', 'Target Schema Privileges',
                            ConfigAttributeType.STRING, False, False,
                            description='Grant privileges to newly created schemas. Choose from USAGE, SELECT.',
                            placeholder_value='SELECT'),
             ConfigProperty('add_metadata_columns', 'Add Metadata Columns', ConfigAttributeType.BOOLEAN, False, False,
-                           description='Metadata columns add extra row level information about data ingestions, '
+                           description='Metadata columns add extra row level information about data ingestion, '
                                        '(i.e. when was the row read in source, when was inserted or deleted in '
                                        'postgres etc.) Metadata columns are creating automatically by adding extra '
                                        'columns to the tables with a column prefix `_SDC_`. The column names are '
@@ -132,13 +141,6 @@ class PostgresTargetConnector(C8Connector):
                                        '`_SDC_DELETED_AT` metadata column. Without the `add_metadata_columns` option '
                                        'the deleted rows from singer taps will not be recognisable in Postgres.',
                            default_value='false'),
-            ConfigProperty('hard_delete', 'Hard Delete', ConfigAttributeType.BOOLEAN, False, False,
-                           description='When `hard_delete` option is true then DELETE SQL commands will be performed '
-                                       'in Postgres to delete rows in tables. It is achieved by continuously checking '
-                                       'the `_SDC_DELETED_AT` metadata column sent by the singer tap. Due to deleting '
-                                       'rows requires metadata columns, `hard_delete` option automatically enables the'
-                                       ' `add_metadata_columns` option as well.',
-                           default_value='false'),
             ConfigProperty('data_flattening_max_level', 'Data Flattening Maximum Level', ConfigAttributeType.INT, False,
                            False,
                            description='Object type RECORD items from taps can be transformed to flattened columns by '
