@@ -19,7 +19,10 @@ def validate_config(config):
         'port',
         'user',
         'password',
-        'dbname'
+        'dbname',
+        'default_target_schema',
+        'target_table',
+        'hard_delete',
     ]
 
     # Check if mandatory keys exist
@@ -159,20 +162,21 @@ def primary_column_names(stream_schema_message):
     return [safe_column_name(p) for p in stream_schema_message['key_properties']]
 
 
-def stream_name_to_dict(stream_name, separator='-'):
+def stream_name_to_dict(stream_name, separator='-', table_name=''):
     catalog_name = None
     schema_name = None
-    table_name = stream_name
+    explicit_table_name = not ''.__eq__(table_name)
+    table_name = table_name if explicit_table_name else stream_name
 
     # Schema and table name can be derived from stream if it's in <schema_nama>-<table_name> format
     s = stream_name.split(separator)
     if len(s) == 2:
         schema_name = s[0]
-        table_name = s[1]
+        table_name = table_name if explicit_table_name else s[1]
     if len(s) > 2:
         catalog_name = s[0]
         schema_name = s[1]
-        table_name = '_'.join(s[2:])
+        table_name = table_name if explicit_table_name else '_'.join(s[2:])
 
     return {
         'catalog_name': catalog_name,
@@ -245,10 +249,11 @@ class DbSync:
             #           }
             config_default_target_schema = self.connection_config.get('default_target_schema', '').strip()
             config_schema_mapping = self.connection_config.get('schema_mapping', {})
+            config_target_table = self.connection_config.get('target_table', '').strip()
 
             stream_name = stream_schema_message['stream']
-            stream_schema_name = stream_name_to_dict(stream_name)['schema_name']
-            stream_table_name = stream_name_to_dict(stream_name)['table_name']
+            stream_schema_name = stream_name_to_dict(stream_name, table_name=config_target_table)['schema_name']
+            stream_table_name = stream_name_to_dict(stream_name, table_name=config_target_table)['table_name']
             if config_schema_mapping and stream_schema_name in config_schema_mapping:
                 self.schema_name = config_schema_mapping[stream_schema_name].get('target_schema')
 
@@ -319,7 +324,8 @@ class DbSync:
                 return []
 
     def table_name(self, stream_name, is_temporary=False, without_schema=False):
-        stream_dict = stream_name_to_dict(stream_name)
+        config_target_table = self.connection_config.get('target_table', '').strip()
+        stream_dict = stream_name_to_dict(stream_name, table_name=config_target_table)
         table_name = stream_dict['table_name']
         pg_table_name = table_name.replace('.', '_').replace('-', '_').lower()
 
